Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2985)

Unified Diff: chrome/browser/tab_contents/web_drop_target_win.cc

Issue 3822007: Move BaseDropTarget and BaseDragSource from base to app/win. Remove the "Base... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/tab_contents/web_drop_target_win.h ('k') | views/widget/drop_target_win.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/tab_contents/web_drop_target_win.cc
===================================================================
--- chrome/browser/tab_contents/web_drop_target_win.cc (revision 62888)
+++ chrome/browser/tab_contents/web_drop_target_win.cc (working copy)
@@ -2,11 +2,11 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
+#include "chrome/browser/tab_contents/web_drop_target_win.h"
+
#include <windows.h>
#include <shlobj.h>
-#include "chrome/browser/tab_contents/web_drop_target_win.h"
-
#include "app/clipboard/clipboard_util_win.h"
#include "app/os_exchange_data.h"
#include "app/os_exchange_data_provider_win.h"
@@ -39,9 +39,9 @@
return DROPEFFECT_NONE;
}
-} // anonymous namespace
+} // namespace
-// InterstitialDropTarget is like a BaseDropTarget implementation that
+// InterstitialDropTarget is like a app::win::DropTarget implementation that
// WebDropTarget passes through to if an interstitial is showing. Rather than
// passing messages on to the renderer, we just check to see if there's a link
// in the drop data and handle links as navigations.
@@ -81,11 +81,8 @@
DISALLOW_COPY_AND_ASSIGN(InterstitialDropTarget);
};
-///////////////////////////////////////////////////////////////////////////////
-// WebDropTarget, public:
-
WebDropTarget::WebDropTarget(HWND source_hwnd, TabContents* tab_contents)
- : BaseDropTarget(source_hwnd),
+ : app::win::DropTarget(source_hwnd),
tab_contents_(tab_contents),
current_rvh_(NULL),
drag_cursor_(WebDragOperationNone),
« no previous file with comments | « chrome/browser/tab_contents/web_drop_target_win.h ('k') | views/widget/drop_target_win.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698